import { NextRequest, NextResponse } from "next/server"
import { auth } from "@/auth"
import { db } from "@/lib/db"
import { z } from "zod"

const updateProductSchema = z.object({
  principal: z.number().positive("本金必须大于0"),
  depositDate: z.string().nullable().optional(),
  endDate: z.string().nullable().optional(),
  currentNetValue: z.number().nullable().optional(),
  annualRate: z.number().nullable().optional(),
  currency: z.string().default("RMB"),
  notes: z.string().nullable().optional(),
}).refine((data) => {
  // 如果有开始时间、结束时间、本金、当前净值，则不需要年化利率（会自动计算）
  // 否则至少需要当前净值或年化利率中的一个
  const hasCompleteInfo = data.depositDate && data.endDate && data.principal && data.currentNetValue
  const hasEitherValue = data.currentNetValue !== null || data.annualRate !== null
  
  return hasCompleteInfo || hasEitherValue
}, {
  message: "请提供足够的信息：要么提供当前净值或年化利率，要么提供完整的时间和净值信息",
  path: ["currentNetValue", "annualRate"]
})

export async function PUT(
  request: NextRequest,
  { params }: { params: { id: string } }
) {
  try {
    const session = await auth()
    
    if (!session?.user?.id) {
      return NextResponse.json({ error: "Unauthorized" }, { status: 401 })
    }

    // 检查产品是否存在且属于当前用户
    const existingProduct = await db.financeProduct.findUnique({
      where: {
        id: params.id,
      },
    })

    if (!existingProduct) {
      return NextResponse.json({ error: "Product not found" }, { status: 404 })
    }

    if (existingProduct.userId !== session.user.id) {
      return NextResponse.json({ error: "Forbidden" }, { status: 403 })
    }

    const body = await request.json()
    if (process.env.NODE_ENV === 'development') {
      console.log("Received update request body:", body)
    }
    
    // 预处理数据：将空字符串转换为null
    const processedBody = {
      ...body,
      currentNetValue: body.currentNetValue === "" || body.currentNetValue === null ? null : Number(body.currentNetValue),
      annualRate: body.annualRate === "" || body.annualRate === null ? null : Number(body.annualRate),
      principal: Number(body.principal),
      depositDate: body.depositDate || null,
      endDate: body.endDate || null,
      currency: body.currency || "RMB",
      notes: body.notes || null,
    }

    if (process.env.NODE_ENV === 'development') {
      console.log("Processed update request body:", processedBody)
    }

    const validatedData = updateProductSchema.parse(processedBody)
    if (process.env.NODE_ENV === 'development') {
      console.log("Validated update data:", validatedData)
    }

    // 检测哪些关键字段发生了变化
    const depositDateChanged = (existingProduct.depositDate?.toISOString()?.split('T')[0]) !== (validatedData.depositDate ? new Date(validatedData.depositDate).toISOString()?.split('T')[0] : null)
    const endDateChanged = (existingProduct.endDate?.toISOString()?.split('T')[0]) !== (validatedData.endDate ? new Date(validatedData.endDate).toISOString()?.split('T')[0] : null)
    const principalChanged = existingProduct.principal !== validatedData.principal
    const currentNetValueChanged = existingProduct.currentNetValue !== validatedData.currentNetValue
    const annualRateChanged = existingProduct.annualRate !== validatedData.annualRate

    if (process.env.NODE_ENV === 'development') {
      console.log("Field changes detected:", {
        depositDateChanged,
        endDateChanged, 
        principalChanged,
        currentNetValueChanged,
        annualRateChanged
      })
      
      console.log("Existing vs New values:", {
        existingDepositDate: existingProduct.depositDate?.toISOString(),
        newDepositDate: validatedData.depositDate ? new Date(validatedData.depositDate).toISOString() : null,
        existingEndDate: existingProduct.endDate?.toISOString(), 
        newEndDate: validatedData.endDate ? new Date(validatedData.endDate).toISOString() : null,
        existingPrincipal: existingProduct.principal,
        newPrincipal: validatedData.principal,
        existingCurrentNetValue: existingProduct.currentNetValue,
        newCurrentNetValue: validatedData.currentNetValue,
        existingAnnualRate: existingProduct.annualRate,
        newAnnualRate: validatedData.annualRate
      })
    }

    // 计算相关字段
    let calculatedValues = {
      profit: existingProduct.profit,
      dailyProfit: existingProduct.dailyProfit,
      monthlyProfit: existingProduct.monthlyProfit,
      calculatedAnnualRate: existingProduct.calculatedAnnualRate,
      averageAnnualProfit: existingProduct.averageAnnualProfit,
    }

    // 验证日期
    let depositDate: Date | null = null
    let endDate: Date | null = null
    let days = 0

    if (validatedData.depositDate && validatedData.endDate) {
      depositDate = new Date(validatedData.depositDate)
      endDate = new Date(validatedData.endDate)
      
      if (isNaN(depositDate.getTime()) || isNaN(endDate.getTime())) {
        return NextResponse.json(
          { error: "无效的日期格式" },
          { status: 400 }
        )
      }

      days = Math.max(1, Math.floor((endDate.getTime() - depositDate.getTime()) / (1000 * 60 * 60 * 24)))
    }

    // 智能重新计算逻辑
    const timeOrProfitChanged = depositDateChanged || endDateChanged || currentNetValueChanged || principalChanged
    const onlyAnnualRateChanged = annualRateChanged && !timeOrProfitChanged

    if (timeOrProfitChanged) {
      if (process.env.NODE_ENV === 'development') {
        console.log("时间或利润相关字段发生变化，重新计算年化利率和相关收益")
      }
      
      // 重新计算利润
      if (validatedData.currentNetValue !== null && validatedData.currentNetValue !== undefined) {
        calculatedValues.profit = validatedData.currentNetValue - validatedData.principal
      }

      // 自动重新计算年化利率
      if (validatedData.currentNetValue && depositDate && endDate && days > 0) {
        const totalReturn = validatedData.currentNetValue - validatedData.principal
        const dailyReturn = totalReturn / days
        const annualReturn = (dailyReturn * 365) / validatedData.principal
        validatedData.annualRate = annualReturn * 100 // 转换为百分比
        if (process.env.NODE_ENV === 'development') {
          console.log("重新计算的年化利率:", validatedData.annualRate)
        }
      }

      // 重新计算基于年化利率的三个平均收益
      if (calculatedValues.profit !== null && days > 0) {
        calculatedValues.dailyProfit = calculatedValues.profit / days
        calculatedValues.monthlyProfit = calculatedValues.dailyProfit * 30
        calculatedValues.calculatedAnnualRate = ((calculatedValues.dailyProfit * 365) / validatedData.principal) * 100
        calculatedValues.averageAnnualProfit = calculatedValues.dailyProfit * 365
        if (process.env.NODE_ENV === 'development') {
          console.log("重新计算的平均收益:", {
            dailyProfit: calculatedValues.dailyProfit,
            monthlyProfit: calculatedValues.monthlyProfit,
            averageAnnualProfit: calculatedValues.averageAnnualProfit
          })
        }
      }
    } else if (onlyAnnualRateChanged) {
      if (process.env.NODE_ENV === 'development') {
        console.log("仅年化利率发生变化，重新计算利润")
      }
      
      // 基于年化利率重新计算当前净值和利润
      if (validatedData.annualRate && depositDate && endDate && days > 0) {
        const calculatedNetValue = validatedData.principal * (1 + ((validatedData.annualRate / 100) * days) / 365)
        validatedData.currentNetValue = calculatedNetValue
        calculatedValues.profit = calculatedNetValue - validatedData.principal
        if (process.env.NODE_ENV === 'development') {
          console.log("基于年化利率重新计算的净值和利润:", {
            currentNetValue: validatedData.currentNetValue,
            profit: calculatedValues.profit
          })
        }

        // 重新计算其他收益指标
        if (calculatedValues.profit !== null && days > 0) {
          calculatedValues.dailyProfit = calculatedValues.profit / days
          calculatedValues.monthlyProfit = calculatedValues.dailyProfit * 30
          calculatedValues.calculatedAnnualRate = ((calculatedValues.dailyProfit * 365) / validatedData.principal) * 100
          calculatedValues.averageAnnualProfit = calculatedValues.dailyProfit * 365
        }
      }
    } else {
      if (process.env.NODE_ENV === 'development') {
        console.log("未检测到关键字段变化，保持现有计算值")
      }
      
      // 如果没有关键变更，但仍需要确保基本计算正确
      if (validatedData.currentNetValue !== null && validatedData.currentNetValue !== undefined) {
        calculatedValues.profit = validatedData.currentNetValue - validatedData.principal
        
        if (days > 0 && calculatedValues.profit !== null) {
          calculatedValues.dailyProfit = calculatedValues.profit / days
          calculatedValues.monthlyProfit = calculatedValues.dailyProfit * 30
          calculatedValues.calculatedAnnualRate = ((calculatedValues.dailyProfit * 365) / validatedData.principal) * 100
          calculatedValues.averageAnnualProfit = calculatedValues.dailyProfit * 365
        }
      }
    }

    if (process.env.NODE_ENV === 'development') {
      console.log("最终计算值:", calculatedValues)
    }

    const updatedProduct = await db.financeProduct.update({
      where: {
        id: params.id,
      },
      data: {
        principal: validatedData.principal,
        depositDate: depositDate,
        endDate: endDate,
        currentNetValue: validatedData.currentNetValue || null,
        annualRate: validatedData.annualRate || null,
        currency: validatedData.currency,
        notes: validatedData.notes,
        ...calculatedValues,
      },
    })

    if (process.env.NODE_ENV === 'development') {
      console.log("Updated product:", updatedProduct)
    }

    // 准备智能计算状态信息
    let smartCalculationInfo = {
      hasSmartCalculation: false,
      calculationType: "none" as "time_profit_changed" | "annual_rate_changed" | "none",
      message: "",
      recalculatedFields: [] as string[]
    }

    if (process.env.NODE_ENV === 'development') {
      console.log("Preparing smart calculation info with flags:", {
        timeOrProfitChanged,
        onlyAnnualRateChanged
      })
    }

    if (timeOrProfitChanged) {
      smartCalculationInfo = {
        hasSmartCalculation: true,
        calculationType: "time_profit_changed",
        message: "检测到时间或利润相关字段变化，已自动重新计算年化利率和相关收益",
        recalculatedFields: ["年化利率", "平均日收益", "平均月收益", "平均年收益"]
      }
      if (process.env.NODE_ENV === 'development') {
        console.log("Setting smart calculation for time_profit_changed")
      }
    } else if (onlyAnnualRateChanged) {
      smartCalculationInfo = {
        hasSmartCalculation: true,
        calculationType: "annual_rate_changed", 
        message: "检测到年化利率变化，已自动重新计算当前净值和利润",
        recalculatedFields: ["当前净值", "利润", "平均日收益", "平均月收益", "平均年收益"]
      }
      if (process.env.NODE_ENV === 'development') {
        console.log("Setting smart calculation for annual_rate_changed")
      }
    } else {
      smartCalculationInfo = {
        hasSmartCalculation: false,
        calculationType: "none",
        message: "未检测到关键字段变化，保持现有计算值",
        recalculatedFields: []
      }
      if (process.env.NODE_ENV === 'development') {
        console.log("Setting smart calculation for none")
      }
    }

    if (process.env.NODE_ENV === 'development') {
      console.log("Final smart calculation info:", smartCalculationInfo)
    }

    return NextResponse.json({
      ...updatedProduct,
      smartCalculation: smartCalculationInfo
    })
  } catch (error) {
    console.error("Error in PUT /api/products/[id]:", error)
    
    if (error instanceof z.ZodError) {
      console.error("Zod validation errors:", error.errors)
      return NextResponse.json(
        { 
          error: "数据验证失败", 
          details: error.errors.map(err => ({
            field: err.path.join('.'),
            message: err.message
          }))
        },
        { status: 400 }
      )
    }

    return NextResponse.json(
      { error: "Internal server error" },
      { status: 500 }
    )
  }
}

export async function DELETE(
  request: NextRequest,
  { params }: { params: { id: string } }
) {
  try {
    const session = await auth()
    
    if (!session?.user?.id) {
      return NextResponse.json({ error: "Unauthorized" }, { status: 401 })
    }

    const product = await db.financeProduct.findUnique({
      where: {
        id: params.id,
      },
    })

    if (!product) {
      return NextResponse.json({ error: "Product not found" }, { status: 404 })
    }

    if (product.userId !== session.user.id) {
      return NextResponse.json({ error: "Forbidden" }, { status: 403 })
    }

    await db.financeProduct.delete({
      where: {
        id: params.id,
      },
    })

    return NextResponse.json({ message: "Product deleted successfully" })
  } catch (error) {
    console.error("Error deleting product:", error)
    return NextResponse.json(
      { error: "Internal server error" },
      { status: 500 }
    )
  }
} 